@@ -449,11 +449,6 @@ void sftpProtocol::setHost(const QString& h, quint16 port, const QString& user,
 
   mUsername = user;
   mPassword = pass;
-
-  if (user.isEmpty()) {
-    KUser u;
-    mUsername = u.loginName();
-  }
 }
 
 void sftpProtocol::openConnection() {
@@ -1169,13 +1164,16 @@ void sftpProtocol::put(const KUrl& url, int permissions, KIO::JobFlags flags) {
         } // flags & KIO::Resume
 
         if (file == NULL) {
-          kDebug(KIO_SFTP_DB) << "####################### COULD NOT WRITE " << dest << " permissions=" << permissions;
+          kDebug(KIO_SFTP_DB) << "COULD NOT WRITE " << dest
+                              << " permissions=" << permissions
+                              << " error=" << ssh_get_error(mSession);
           if (sftp_get_error(mSftp) == SSH_FX_PERMISSION_DENIED) {
-              error(KIO::ERR_WRITE_ACCESS_DENIED, QString::fromUtf8(dest));
+            error(KIO::ERR_WRITE_ACCESS_DENIED, QString::fromUtf8(dest));
           } else {
             error(KIO::ERR_CANNOT_OPEN_FOR_WRITING, QString::fromUtf8(dest));
           }
           sftp_attributes_free(sb);
+          finished();
           return;
         } // file
       } // dest.isEmpty
@@ -1443,8 +1441,7 @@ void sftpProtocol::listDir(const KUrl& url) {
         entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
         break;
       case SSH_FILEXFER_TYPE_SYMLINK:
-        entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
-        entry.insert(KIO::UDSEntry::UDS_LINK_DEST, QLatin1String("Dummy Link Target"));
+        entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFLNK);
         break;
       case SSH_FILEXFER_TYPE_SPECIAL:
       case SSH_FILEXFER_TYPE_UNKNOWN:
